@@ -354,19 +354,29 @@ panel_set_bg(MBPanel *panel, int bg_type, char *bg_spec)
 		      &panel->xcol ))
 	{
 
+	  /*
 	  XAllocColor(panel->dpy, 
 		      DefaultColormap(panel->dpy, panel->screen),
 		      &panel->xcol);
+	  */
 
 	  XSetWindowBackground(panel->dpy, panel->win, 
-			       panel->xcol.pixel);
+			       mb_pixbuf_lookup_x_pixel(panel->pb, 
+							panel->xcol.red >> 8,
+							panel->xcol.green >> 8,
+							panel->xcol.blue >> 8, 0));
+
+	  //			       panel->xcol.pixel);
 	  XClearWindow(panel->dpy, panel->win);
 
 	  if (panel->bg_pxm != None) 
 	    XFreePixmap(panel->dpy, panel->bg_pxm);
 	  panel->bg_pxm = None;
 	  
-	  snprintf(xprop_def, 32, "rgb:%li", panel->xcol.pixel);
+	  snprintf(xprop_def, 32, "rgb:%li", mb_pixbuf_lookup_x_pixel(panel->pb, 
+								      panel->xcol.red >> 8,
+								      panel->xcol.green >> 8,
+								      panel->xcol.blue >> 8, 0));
 	}
       panel->root_pixmap_id = 0;
       break;
@@ -814,10 +824,19 @@ panel_handle_dock_request(MBPanel *panel, Window win)
 
   util_get_command_str_from_win(panel, win, &cmd_str); /* cmd_str freed l8r */
 
-  if (session_preexisting_win_matches_wanted(panel, win, cmd_str))
+  if (session_preexisting_restarting(panel))
     {
-      app_origin_dist = panel->session_init_offset;
-      session_preexisting_clear_current(panel);
+      if (session_preexisting_win_matches_wanted(panel, win, cmd_str))
+	{
+	  app_origin_dist = panel->session_init_offset;
+	  session_preexisting_clear_current(panel);
+	}
+      else
+	{
+	  DBG("%s() defering winid %li ( %s) \n", __func__, win, cmd_str );
+	  panel->session_defered_wins[panel->n_session_defered_wins++] = win;
+	  return;
+	}
     }
 
   new_papp = panel_app_new(panel, win, cmd_str);
